package space.rocketnine.fastingassistant;

import android.content.Intent;
import android.graphics.drawable.ColorDrawable;
import android.net.Uri;
import android.os.Bundle;
import android.text.Html;
import android.text.method.LinkMovementMethod;
import android.view.View;
import android.widget.TextView;

import androidx.appcompat.app.ActionBar;
import androidx.appcompat.app.AppCompatActivity;

import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.StringWriter;

public class AboutActivity extends AppCompatActivity {

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_about);

        // Set action bar background.
        ActionBar actionBar = getSupportActionBar();
        actionBar.setBackgroundDrawable(new ColorDrawable(getResources().getColor(R.color.app_color)));


        final TextView authorEmail = (TextView) findViewById(R.id.text_author_email);
        authorEmail.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                Intent e = new Intent(Intent.ACTION_SENDTO, Uri.fromParts("mailto", getString(R.string.my_email_address), null));
                String[] to = {getString(R.string.my_email_address)};
                e.putExtra(Intent.EXTRA_EMAIL, to);
                e.putExtra(Intent.EXTRA_SUBJECT, "Fasting Assistant");
                startActivity(Intent.createChooser(e, getString(R.string.send_email)));
            }
        });

        final TextView authorWebsite = (TextView) findViewById(R.id.text_author_website);
        authorWebsite.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                FastingAssistant.openURL(AboutActivity.this, FastingAssistant.URL_ROCKETNINELABS);
            }
        });

        final TextView textSourceCode = (TextView) findViewById(R.id.text_source_code);
        textSourceCode.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                FastingAssistant.openURL(AboutActivity.this, FastingAssistant.URL_SOURCE);
            }
        });

        final TextView licenseText = (TextView) findViewById(R.id.text_license);
        try {
            InputStream reader = getAssets().open("gpl.html");
            licenseText.setText(Html.fromHtml(getStringFromInputStream(reader)));
        } catch (IOException e) {
            e.printStackTrace();
        }
        licenseText.setMovementMethod(LinkMovementMethod.getInstance());
    }

    public static String getStringFromInputStream(InputStream stream) throws IOException {
        int n = 0;
        char[] buffer = new char[1024 * 4];
        InputStreamReader reader = new InputStreamReader(stream, "UTF8");
        StringWriter writer = new StringWriter();
        while (-1 != (n = reader.read(buffer))) writer.write(buffer, 0, n);
        return writer.toString();
    }
}